/* this is session.c file.
 * this is part of the libspopc library sources
 * copyright  2002 Benoit Rouits <brouits@free.fr>
 * released under the terms of GNU LGPL
 * (GNU Lesser General Public Licence).
 * libspopc offers simple API for a pop3 client (MTA).
 * See RFC 1725 for pop3 specifications.
 * more information on http://brouits.free.fr/libspopc/
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <netdb.h>
#include <unistd.h>
#include <netinet/in.h>
#include <sys/types.h>
#include <sys/socket.h>

int pop3_prepare(const char* servername, const int port, struct sockaddr_in* connection, struct hostent* server){
/* prepares the pop session and returns a socket descriptor */
int sock;
	bzero((char*)connection,sizeof(struct sockaddr_in));
	server=gethostbyname(servername);
	if(!server){
		perror("pop3_prepare.gethostbyname");
		return(-1);
	}
	bcopy(server->h_addr,(char*)&(connection->sin_addr.s_addr),server->h_length);
	connection->sin_family=AF_INET;
	connection->sin_port=htons(port?port:110);
	sock=socket(AF_INET,SOCK_STREAM,0);
	if(-1==sock){
		perror("pop3_prepare.socket");
		free(server);
	}
	return(sock);
}

char* pop3_connect(int sock, struct sockaddr_in* connection){
/* connects to the server through the sock and returns server's welcome */
int r;
char* buf;

#ifdef EBUG
	fprintf(stderr,"<pop3_connect>\n");
#endif
	r=connect(sock,(struct sockaddr*)connection,(socklen_t)sizeof(*connection));
	if(r==-1){
		perror("pop3_connect.connect");
		return(NULL);
	}
	buf=(char*)malloc(64);
	if(!buf){
		perror("pop3_connect.malloc");
		return(NULL);
	}
	r=recv(sock,buf,64,0);
	buf[r]='\0';
#ifdef EBUG
	fprintf(stderr,"recv %s",buf);
	fprintf(stderr,"</pop3_connect>\n");
#endif
	return(buf);
}

void pop3_disconnect(int sock){
/* close socket  */
	if(sock>0){
		close(sock);
	}
}
